#!/etc/opt/openit/perl

BEGIN {
    push @INC, "/opt/openit/contrib/lib";
}

use strict;
use FileHandle;

use OpeniT::Contrib::Config;

my $config = new OpeniT::Contrib::Config;      # Reads default config file(s)
my $etc = $config->{CONFIG_DIR};

my $filter_dir = "$etc/filtrator";

my $dirhandle = new FileHandle;
my $ok = opendir( $dirhandle, $filter_dir );

if ( ! $ok ) {
    die "Couldn't open $filter_dir, $!\n";
}

#
# Find all license filters to modify, only base licpoll2
# filters are to be considered
#
my @fix_filters = ();
while ( my $entry = readdir( $dirhandle ) ) {
    if ( $entry =~ /^license-/ && $entry !~ /-old.conf/
	 && $entry !~ /-flex-log/ && $entry !~ /conf.unmodified/
	 && $entry !~ /sam/ ) {
	push @fix_filters, $entry;
    }
}
closedir( $dirhandle);

#
# Modify all filtesr
#
foreach my $filter (@fix_filters) {
    &update_filter($filter);
}

exit;

sub update_filter {
    my ($filter) = @_;

    print "Updating filter '$filter'\n";
    my $file = "$filter_dir/$filter";

    # Read filter file
    open(FILT, $file) || die "Couldn't read '$file'\n";
    my @lines = <FILT>;
    close(FILT);

    my $modified = &check_and_fix_primetime_filter( \@lines );
    $modified += &check_and_fix_concurrent_filter( \@lines );

    if ($modified) {
	if( ! rename $file, "$file.unmodified" ) {
	    die "Couldn't move old filter file '$file' away\n";
	}

	if( ! open(FILT, ">$file") ) {
	    print "Couldn't write new filter file '$file\n";
	    rename "$file.unmodified", $file;
	    die "\n";
	}

	print FILT @lines;
	close(FILT);
    } else {
	print "Already updated, skipping\n";
    }
}

sub check_and_fix_primetime_filter {
    my ($lines) = @_;

    # Check (and update prime-time filter ) if filter has been modified
    if ( ! grep { s/'prime'|'non-prime'/'undef'/g } @{$lines} ) {
	return 0;
    }

    return 1;
}

sub check_and_fix_concurrent_filter {
    my ($lines) = @_;

    my $line = 0;

    # Find Concurrent filter
    while ( $$lines[$line] !~ /filter\(String\)=\"Concurrent/ ) {
	$line++;
    }

    # Then compare line
    while ( $$lines[$line] !~ /compare\(String\)/ ) {
	$line++
    }

    if ( $$lines[$line] =~ s/,primetime// ) {
	return 1;
    }

    return 0;
}
